@@ -9,9 +9,10 @@ def find_px_angles(
     hough_accumulator: numpy.ndarray,
     theta: numpy.ndarray,
 ) -> Tuple[np.ndarray, np.ndarray]:
-    """Find the most significant angles in a Hough transform.
+    """
+    Find the most significant angles in a Hough transform.
 
-    Peaks in the Hough transform a first found with a simple max filter and then refined via interpolation of the
+    Peaks in the Hough transform are first found with a simple max filter and then refined via interpolation of the
     surrounding peak.
 
     Note, peak angles are not allowed to be within pi/10 of each other.
