@@ -8,7 +8,8 @@ from skimage import transform as skit
 def do_hough(
     binary: numpy.ndarray, theta_min: float, theta_max: float, numtheta: int = 1500
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-    """Perform a Hough line transform on input data.
+    """
+    Perform a Hough line transform on input data.
 
     Resolution in the angle dimension can be increased via numtheta.
 
@@ -28,13 +29,11 @@ def do_hough(
 
     Returns
     -------
-    The 2D Hough space (i.e., accumulator) of the input image
+    A tuple containing:
+        - The 2D Hough space (i.e., accumulator) of the input image.
+        - A 1D array of the angle values corresponding to the Hough accumulator. Angles will range from -pi/4 to 3/4 pi and the length will be equal to numtheta.
+        - A 1D array of the distance values corresponding to the Hough accumulator. This array is entirely determined by skimage.transform.hough_line
 
-    A 1D array of the angle values corresponding to the Hough accumulator. Angles will range from -pi/4 to 3/4 pi
-    and the length will be equal to numtheta.
-
-    A 1D array of the distance values corresponding to the Hough accumulator. This array is entirely determined
-    by skimage.transform.hough_line
     """
     hough = skit.hough_line(binary, theta=np.linspace(theta_min, theta_max, numtheta))
     hough_accumulator = hough[0]
